import pkg_resources

from .. import __version__


APP_ICON = pkg_resources.resource_filename(__name__, 'app_icon.ico')

ST_NAME = "Image to STL"
ST_VERSION = __version__
ST_DESCRIPTION = "Application for converting images to STL (3D model for printing)"
ST_COPYRIGHT = "Copyright (c) 2019-2021 Alexander Baskikh"
ST_LICENSE_LINK = "https://github.com/baskiton/Img2STL/blob/main++/LICENSE"
ST_LICENSE =    \
        "MIT License\n\n"       \
        "Copyright (c) 2019-2021 Alexander Baskikh\n\n" \
        "Permission is hereby granted, free of charge, to any person obtaining a copy " \
        "of this software and associated documentation files (the \"Software\"), to deal "      \
        "in the Software without restriction, including without limitation the rights to "      \
        "use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies "        \
        "of the Software, and to permit persons to whom the Software is furnished to do "       \
        "so, subject to the following conditions:\n\n"  \
        "The above copyright notice and this permission notice shall be included in all "       \
        "copies or substantial portions of the Software.\n\n"   \
        "THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR " \
        "IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, "     \
        "FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE "  \
        "AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, "    \
        "WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN "      \
        "CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE."
